<?php

namespace ShopEngine\Core\PageTemplates;

defined( 'ABSPATH' ) || exit;

use ShopEngine\Traits\Singleton;


class Page_Templates {
	use Singleton;

	private $templateList = [];
	private $listedCollected = false;

	public function init() {

		$templates = $this->getTemplates();

		foreach ( $templates as $key => $template ) {

			if ( isset( $template['class'] ) && $template['class'] ) {

				new $template['class']();
				//$template['class']::instance()->init();
			}

		}
	}


	public function getTemplates() {

		if ( ! $this->listedCollected ) {
			$this->templateList    = apply_filters( 'shopengine/page_templates', $this->get_list());
			$this->listedCollected = true;
		}

		return $this->templateList;
	}

	public function getTemplate( $slug ) {
		$page_templates = $this->getTemplates();

		return $page_templates[ $slug ] ?? [];
	}


	public function get_list() {
		return  [
			'shop'                => [
				'title'   => esc_html__( 'Shop', 'shopengine' ),
				'package' => 'free',
				'class'   => 'ShopEngine\Core\Page_Templates\Hooks\Shop',
				'opt_key' => 'shop',
				'css'     => 'shop',
			],
			'archive'             => [
				'title'   => esc_html__( 'Archive', 'shopengine' ),
				'package' => 'free',
				'class'   => 'ShopEngine\Core\Page_Templates\Hooks\Archive',
				'opt_key' => 'archive',
				'css'     => 'archive',
			],
			'single'              => [
				'title'   => esc_html__( 'Single', 'shopengine' ),
				'package' => 'free',
				'class'   => 'ShopEngine\Core\Page_Templates\Hooks\Single',
				'opt_key' => 'single',
				'css'     => 'single',
			],
			'cart'                => [
				'title'   => esc_html__( 'Cart', 'shopengine' ),
				'package' => 'free',
				'class'   => 'ShopEngine\Core\Page_Templates\Hooks\Cart',
				'opt_key' => 'cart',
				'css'     => 'cart',
			],
			// 'empty_cart'          => [
			// 	'title'   => esc_html__( 'Empty Cart page', 'shopengine' ),
			// 	'package' => 'free',
			// 	'class'   => 'ShopEngine\Core\Page_Templates\Hooks\Empty_Cart',
			// 	'opt_key' => 'empty_cart',
			// 	'css'     => 'empty-cart',
			// ],
			'checkout'            => [
				'title'   => esc_html__( 'Checkout', 'shopengine' ),
				'package' => 'free',
				'class'   => 'ShopEngine\Core\Page_Templates\Hooks\Checkout',
				'opt_key' => 'checkout',
				'css'     => 'checkout',
			],
		];
	}
}
