<?php

namespace ShopEngine\Modules\Comparison;

use ShopEngine\Base\Api;
use ShopEngine\Modules\Swatches\Helper;
use ShopEngine\Modules\Swatches\Swatches;

class Route extends Api {

	public function config() {

		$this->prefix = 'comparison';
		$this->param  = "";
	}


	private function prepare_html($content = []) {

		$attr = [];
		$ids  = [];

		foreach($content as $pid) {

			if(empty($pid)) {
				continue;
			}

			$prod = wc_get_product($pid);

			if(empty($prod)) {
				continue;
			}

			$ids[] = $pid;

			$attr['image'][$pid] = $prod->get_image();
			$attr['url'][$pid]   = $prod->add_to_cart_url();
			$attr['name'][$pid]  = $prod->get_name();


			$attr['stock'][$pid]  = $prod->get_stock_status();
			$attr['stock2'][$pid] = $prod->get_stock_quantity();
			$attr['sku'][$pid]    = $prod->get_sku();
			//$attr['type'][$pid] = $prod->get_type();

			$attr['price'][$pid]['regular'] = $prod->get_regular_price();
			$attr['price'][$pid]['sale']    = $prod->get_sale_price();
			$attr['price'][$pid]['price']   = $prod->get_price();
			$attr['price'][$pid]['htm']     = $prod->get_price_html();


			if($prod->get_rating_counts()) {

				$attr['rating_count'][$pid] = $prod->get_rating_counts();
			}

			if($prod->get_average_rating()) {

				$attr['rating'][$pid] = $prod->get_average_rating();
			}

			if($prod->get_review_count()) {

				$attr['review_count'][$pid] = $prod->get_review_count();
			}

			if($prod->has_weight()) {

				$attr['weight'][$pid] = $prod->get_weight();
			}

			if($prod->has_attributes()) {

				$ats = $prod->get_attributes();

				foreach($ats as $at) {

					$at_id = $at->get_id();
					$at_id = empty($at_id) ? md5($at->get_name()) : $at_id;

					$assigned_terms = $at->get_options();

					$attr['attr'][$pid][$at_id]['name']    = wc_attribute_label($at->get_name());
					$attr['attr'][$pid][$at_id]['pa_name'] = $at->get_name();
					$attr['attr'][$pid][$at_id]['txo']     = '';

					$attr['attr_loop'][$at_id]['nm']        = $attr['attr'][$pid][$at_id]['name'];
					$attr['attr_loop'][$at_id]['pid'][$pid] = $pid;

					if($at->is_taxonomy()) {

						$txo_meta = Helper::get_tax_attribute($at->get_name());

						$attr['attr'][$pid][$at_id]['txo'] = $txo_meta->attribute_type;

						foreach($assigned_terms as $assigned_term) {

							$term = get_term_by('id', $assigned_term, $at->get_name());

							if($txo_meta->attribute_type === Swatches::PA_COLOR) {

								$t_val = get_term_meta($assigned_term, 'shopengine_color', true);

								$attr['attr'][$pid][$at_id]['tval'][$assigned_term] = $t_val;
							}

							$attr['attr'][$pid][$at_id]['val'][$assigned_term] = $term->name;
						}

					} else {
					    
						foreach($assigned_terms as $idx => $term) {
							$attr['attr'][$pid][$at_id]['val'][$idx] = $term;
						}
					}
				}
			}

			if($prod->has_dimensions()) {

				$attr['dim'][$pid]['len'] = $prod->get_length();
				$attr['dim'][$pid]['wd']  = $prod->get_width();
				$attr['dim'][$pid]['ht']  = $prod->get_height();

			}
		}

		?>

        <div>
            <div class="shopengine-comparison-container">
                <div class="shopengine-comparison">
                    <h2><?php echo __('Product comparison', 'shopengine') ?></h2>

                    <div class="comparison-table-wrap">

                        <table class="table table-bordered">

                            <tbody> <?php

							foreach($attr as $key => $info) { ?>

                                <tr> <?php

									if($key === 'image') {

										echo '<td> </td>';

										foreach($ids as $id) {
											?>
											<td class="first--row">
												<a class="shopengine-remove-action badge-comparison" data-pid="<?php echo esc_attr( $id ); ?>"><i class="eicon-close"></i></a>
												<?php echo empty($info[$id]) ? '' : $info[$id]; ?>
												<br>
												<a href="<?php echo $attr['url'][$id]; ?>" class="compare-cart-btn"><?php echo esc_html__('Add to cart', 'shopengine'); ?></a>
											</td>
											<?php
										}

									} elseif(
										$key === 'name' ||
										$key === 'rating' ||
										$key === 'stock' ||
										$key === 'weight' ||
										$key === 'sku'
									) {

										echo '<th>' . ucfirst($key) . ' </th>';

										foreach($ids as $id) {

											echo '<td> ' . (empty($info[$id]) ? ' - ' : $info[$id]) . ' </td>';
										}

									} elseif($key === 'price') {

										echo '<th>' . ucfirst($key) . ' </th>';

										foreach($ids as $id) {

											echo '<td><span class="price">' . (empty($info[$id]['htm']) ? '' : $info[$id]['htm']) . '</span></td>';
										}

									} elseif($key === 'dim') {

										echo '<th> ' . __('Dimensions', 'shopengine') . ' </th>';

										foreach($ids as $id) {

											if(!isset($info[$id])) {

												echo '<td> </td>';

												continue;
											}

											echo '<td>' . implode(' * ', $info[$id]) . '</td>';
										}

									} elseif($key === 'attr') {


									} ?>

                                </tr> <?php
							} ?>

							<?php

							if(!empty($attr['attr'])) {

								echo '<tr><th colspan="' . (count($ids) + 1) . '">' . __('Available options', 'shopengine') . ' :</th></tr>';

								foreach($attr['attr_loop'] as $atr_id => $a_inf) {

									echo '<tr>';
									echo '<th>' . ($a_inf['nm']) . '</th>';

									foreach($ids as $id) {

										if(isset($attr['attr'][$id][$atr_id])) {

											if($attr['attr'][$id][$atr_id]['txo'] === Swatches::PA_COLOR) {

												$div = '';

												foreach($attr['attr'][$id][$atr_id]['tval'] as $tid => $t_vl) {
													$div .= '<span class="shopengine-comparison-color-attr" 
														    style="background-color: ' . esc_attr($t_vl) . ';"></span>';
												}

												echo '<td> ' . $div . ' </td>';

											} elseif($attr['attr'][$id][$atr_id]['pa_name'] === 'pa_color') {

												/**
												 * todo - Should we give the color div for woocom default color?
												 * In that case how do we validate it is a valid color name?
												 *
												 */
												echo '<td> ' . implode(', ', $attr['attr'][$id][$atr_id]['val']) . ' </td>';

											} else {

												echo '<td> ' . implode(', ', $attr['attr'][$id][$atr_id]['val']) . ' </td>';
											}

										} else {
											echo '<td> - </td>';
										}
									}

									echo '</tr>';
								}
							} ?>

                            </tbody>
                        </table>
                    </div>
                </div>
            </div>
        </div>
		<?php

	}

	public function get_comparison_table() {

		$data = $this->request->get_params();
		$idd  = $data['pid'];

		$cck           = empty($_COOKIE[Comparison::COOKIE_KEY]) ? '' : $_COOKIE[Comparison::COOKIE_KEY];
		$cck           = explode(',', $cck);
		$content       = array_combine($cck, $cck);
		$content[$idd] = $idd;

		unset($content['']);

		$val = implode(',', $content);

		setcookie(Comparison::COOKIE_KEY, $val, strtotime('+' . Comparison::COOKIE_TIME_IN_DAYS . ' days'), '/');

		$this->prepare_html($content);

		exit();
	}

	public function post_remove() {

		$data = $this->request->get_params();
		$idd  = $data['pid'];

		$cck     = empty($_COOKIE[Comparison::COOKIE_KEY]) ? '' : $_COOKIE[Comparison::COOKIE_KEY];
		$cck     = explode(',', $cck);
		$content = array_combine($cck, $cck);

		unset($content[$idd], $content['']);

		$val = implode(',', $content);

		setcookie(Comparison::COOKIE_KEY, $val, strtotime('+' . Comparison::COOKIE_TIME_IN_DAYS . ' days'), '/');

		$this->prepare_html($content);

		exit();
	}
}
